@@ -3,7 +3,7 @@
 
 #include "plugininterfaces.h"
 
-PluginSettings::PluginSettings(QSet<PluginInterface *>pluginInterfaces, QWidget *parent) :
+PluginSettings::PluginSettings(QList<PluginInterface *>pluginInterfaces, QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::PluginSettings)
 {
