@@ -23,6 +23,8 @@ private:
     MaemoBarcodeWindow *parent;
 
 private slots:
+    void on_radioButtonPressToScan_clicked();
+    void on_radioButtonContinuousScanning_clicked();
     void on_spnAutoFocusDelay_valueChanged(double );
     void on_chkSaveHistory_clicked();
 };
